Translate Toolkit 3.12.0
************************

*Released on 21 December 2023*

This release contains improvements and bug fixes.

Changes
=======

Formats and Converters
----------------------

- Android 

  - Fixed language definitions for some languages
  - Added support for MOKO resources
  - Improved handling of CDATA in strings

- Gettext PO

  - Honor line wrapping configuration when adding unit

- Qt TS2

  - Use correct plurals matching Qt implementation

- Properties

  - Notes behave consistently with other formats

- RESX/RESW

  - Use Windows newlines instead of UNIX ones

- JSON

  - Improved parsing of string keys

- INI

  - Do not treat lines starting with ``rem`` as comments

Contributors
============

This release was made possible by the following people:

Michal Čihař
